aboutsummaryrefslogtreecommitdiffstats
path: root/epan/proto.h
diff options
context:
space:
mode:
authorPascal Quantin <pascal.quantin@gmail.com>2018-11-01 17:17:28 +0100
committerPascal Quantin <pascal.quantin@gmail.com>2018-11-01 17:09:33 +0000
commita99bba4c7c51e5437dd0607c01f58d2f15624bea (patch)
treea99167aec4115bca7f75bdceffe16dd5cf80408b /epan/proto.h
parent24370eae4158ee7db4f4c2cbffbfccc7e021f624 (diff)
Fix "Follow TLS Stream" after ssl -> tls rename
Change-Id: I53be2ae6fae135b2da98ae95deac535bcd37af74 Reviewed-on: https://code.wireshark.org/review/30473 Petri-Dish: Pascal Quantin <pascal.quantin@gmail.com> Tested-by: Petri Dish Buildbot Reviewed-by: Pascal Quantin <pascal.quantin@gmail.com>
Diffstat (limited to 'epan/proto.h')
-rw-r--r--epan/proto.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/proto.h b/epan/proto.h
index d972189393..dbcbb2aeee 100644
--- a/epan/proto.h
+++ b/epan/proto.h
@@ -2397,7 +2397,7 @@ WS_DLL_PUBLIC void proto_heuristic_dissector_foreach(const protocol_t *protocol,
* unchanged. May be NULL.
* @param is_sctp Set to TRUE if the layer list contains SCTP, otherwise
* unchanged. May be NULL.
* @param is_ssl Set to TRUE if the layer list contains SSL/TLS, otherwise
* unchanged. May be NULL.
* @param is_rtp Set to TRUE if the layer list contains RTP, otherwise
* unchanged. May be NULL.
@@ -2406,7 +2406,7 @@ WS_DLL_PUBLIC void proto_heuristic_dissector_foreach(const protocol_t *protocol,
*/
WS_DLL_PUBLIC void proto_get_frame_protocols(const wmem_list_t *layers,
gboolean *is_ip, gboolean *is_tcp, gboolean *is_udp, gboolean *is_sctp,
- gboolean *is_ssl, gboolean *is_rtp, gboolean *is_lte_rlc);
+ gboolean *is_tls, gboolean *is_rtp, gboolean *is_lte_rlc);
/** Check whether a protocol, specified by name, is in a layer list.
* @param layers Protocol layer list
@@ -2397,7 +2397,7 @@ WS_DLL_PUBLIC void proto_heuristic_dissector_foreach(const protocol_t *protocol,
* @param is_sctp Set to TRUE if the layer list contains SCTP, otherwise
* unchanged. May be NULL.
- * @param is_ssl Set to TRUE if the layer list contains SSL/TLS, otherwise
+ * @param is_tls Set to TRUE if the layer list contains SSL/TLS, otherwise
* unchanged. May be NULL.
* @param is_rtp Set to TRUE if the layer list contains RTP, otherwise